@@ -2,7 +2,7 @@ package Perl6::Controls;
 
 use 5.014; use warnings;
 
-our $VERSION = '0.000003';
+our $VERSION = '0.000005';
 
 
 use Keyword::Declare;
@@ -13,7 +13,7 @@ sub import {
 
     keyword for {{{ foreach }}}
 
-    keytype OptIter is /my\s*\$\w+/;
+    keytype OptIter is /(?:my|our|state)\s*\$\w+/;
 
     keyword for (OptIter $iter = '', '(', '^', Int $max, ')') {{{ for <{$iter}> (0..<{$max-1}>) }}}
 
@@ -131,7 +131,7 @@ Perl6::Controls - Add Perl 6 control structures as Perl 5 keywords
 
 =head1 VERSION
 
-This document describes Perl6::Controls version 0.000003
+This document describes Perl6::Controls version 0.000005
 
 
 =head1 SYNOPSIS
